SuchThat

Struct SuchThat 

pub struct SuchThat<A, P> { /* private fields */ }
A value with a proof attached

Implementations

Source

impl<A, P> SuchThat<A, P>

pub fn value(self) -> A

Extracts the value from a proof-attached value

pub fn value_ref(&self) -> &A

Returns a reference to the value of a proof-attached value

Source

impl<A, N, P> SuchThat<Named<A, N>, P>

pub fn extract(self) -> A

Extract the value from a proof-attached named value

pub fn extract_ref(&self) -> &A

Returns a reference to the value of a proof-attached named value